# python-minorimpact



## Build

    $ python setup.py sdist


### PyPi Upload

Old method:

    $ python setup.py sdist upload

New method:

    $ twine upload dist/*

## Installation

### Testing

    $ pip3 install dist/*

### Generally

    $ pip install minorimpact

